ExplorerController class

Constructors

ExplorerController({required ExplorerProvider provider})

Properties

actionStream → Stream<ExplorerAction>
no setter
no setter
currentPath → String
no setter
entryPath → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasUploadFilesCallback → bool
no setter
provider → ExplorerProvider
An entity responsible for navigating the file structure of any type, ex. IoExplorerProvider for io
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<ExplorerState>
no setter

Methods

cancelAction() → void
copy(Entry from, Entry to) → Future<void>
copyEntriesConfirm(List<Entry> entries) → void
copyEntriesRequest(List<Entry> entries) → void
dispose() → void
go(String path) → Future<void>
goEntry(Entry entry) → Future<void>
moveEntriesConfirm(List<Entry> entries) → void
moveEntriesRequest(List<Entry> entries) → void
newDirectory(String name) → Future<void>
newFile(String name) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() → Future<void>
remove(Entry entry) → Future<void>
toString() → String
A string representation of this object.
inherited
uploadLocalFiles() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited