IoExplorerProvider class

Provider for exploring the IO File System

Inheritance

Constructors

IoExplorerProvider({String entryPath = '/'})

Properties

currentPath ↔ String
Explorer actual path
getter/setter pairoverride-getter
entryPath → String
Explorer starts path
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy(Entry from, Entry to) → Future<void>
Copy file or dir
override
go(String path) → Future<List<Entry>>
Navigate to specific path
override
newDirectory(String name) → Future<ExplorerDirectory>
Create new directory at currentPath
override
newFile(String name) → Future<ExplorerFile>
Create new file at currentPath
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Entry entry) → Future<void>
Recursive remove file or dir at currentPath
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited